#version 3.7;

global_settings{ assumed_gamma 1.0 }

#declare ViewSize = 3;
#declare X_CamPos = FramesNumber / 2 * ViewSize - ViewSize / 2;

camera{
	orthographic
	location < X_CamPos, 100, 0 >
	look_at < X_CamPos, 0, 0 >
	right ViewSize * FramesNumber * x
	up ViewSize * z
	sky z
	direction -100 * y
}

light_source{ < 1, 4, 1.5 > * 1000 color srgb 1 }

#include "includes/affineFunctionSetter.inc"
#include "includes/explosionData.inc"

#declare InitialScale = 1;
#declare FinalScale = 1.475;
#declare FireMediaLessScale = 0.45;
#declare InitialTurbulence = 0.05;
#declare FinalTurbulence = 0.5; 

#declare InitialSmokeIntensity = 6;
#declare FinalSmokeIntensity = 3;
#declare HighFireIntensity = 1.25;
#declare LowFireIntensity = 0.1;

#declare ExpendingFrameNumber = 8;
#declare ExplosionLengthFrameNumber = 20;
#declare DirtDispersion = FramesNumber;

#declare DirtRotate = 10;
#declare FireRotate = 2;

//Explosion expension
#for( FrameNum, 0, ExpendingFrameNumber )
	#local CurrentScale = SetWithAffineFunction(0, ExpendingFrameNumber, InitialScale, FinalScale, FrameNum);
	#local CurrentTurbulence = SetWithAffineFunction(0, ExpendingFrameNumber, InitialTurbulence, FinalTurbulence + 0.25, FrameNum);
	#local CurrentFireIntensity = SetWithAffineFunction(0, ExpendingFrameNumber, LowFireIntensity, HighFireIntensity, FrameNum );
	#local SmokeIntensity = SetWithAffineFunction( 0, ExpendingFrameNumber, 0.25, 1, FrameNum );
	sphere{ 0, 1 hollow no_shadow pigment{ color srgbt 1 }
		interior{
			MakeScatteredDirtMedia(< FrameNum * DirtRotate, 0, 0>, 1 /*scale value*/, CurrentTurbulence, SmokeIntensity )
			MakeFireBallMedia(< FrameNum * FireRotate, 0, 0 >, CurrentScale - FireMediaLessScale, 0, CurrentTurbulence, CurrentFireIntensity )
		}
		scale CurrentScale
		translate < FrameNum * ViewSize, 0, 0 >
	}
#end

//Explosion of fire zenith
#for( FrameNum, ExpendingFrameNumber + 1, ExplosionLengthFrameNumber)
	#local CurrentScale = SetWithAffineFunction(ExpendingFrameNumber + 1, ExplosionLengthFrameNumber, FinalScale, FinalScale, FrameNum);
	#local CurrentTurbulence = SetWithAffineFunction(ExpendingFrameNumber + 1, ExplosionLengthFrameNumber, FinalTurbulence + 0.25, FinalTurbulence - 0.25, FrameNum);
	#local CurrentFireIntensity = SetWithAffineFunction(ExpendingFrameNumber + 1, ExplosionLengthFrameNumber, HighFireIntensity, LowFireIntensity, FrameNum );
	sphere{ 0, 1 hollow no_shadow pigment{ color srgbt 1 }
		interior{
			MakeScatteredDirtMedia(< FrameNum * DirtRotate, 0, 0 >, 1 /*scale value*/, CurrentTurbulence, 1 )
			MakeFireBallMedia(< FrameNum * FireRotate, 0, 0 >, CurrentScale - FireMediaLessScale, 0, CurrentTurbulence, CurrentFireIntensity )
		}
		scale CurrentScale
		translate < FrameNum * ViewSize, 0, 0 >
	}
#end

//Absence of fire and scattering of smoke
#for( FrameNum, ExplosionLengthFrameNumber + 1, DirtDispersion - 1 )
	#local CurrentScale = SetWithAffineFunction(ExplosionLengthFrameNumber + 1, DirtDispersion, FinalScale, InitialScale, FrameNum);
	#local SmokeIntensity = SetWithAffineFunction( ExplosionLengthFrameNumber + 1, DirtDispersion, 1, 0.25, FrameNum );
	#local CurrentTurbulence = SetWithAffineFunction(ExplosionLengthFrameNumber + 1, DirtDispersion, FinalTurbulence - 0.25, InitialTurbulence, FrameNum);
	sphere{ 0, 1 hollow no_shadow pigment{ color srgbt 1 }
		interior{
			MakeScatteredDirtMedia(< FrameNum * DirtRotate, 0, 0 >, 1 /*scale value*/, CurrentTurbulence, SmokeIntensity )
		}
		scale CurrentScale
		translate < FrameNum * ViewSize, 0, 0 >
	}
#end